@@ -3,7 +3,7 @@
 extern char *HYDRA_EXIT;
 char *buf;
 
-int start_cisco_enable(int s,int port,unsigned char options,char *miscptr,FILE *fp) {
+int start_cisco_enable(int s,unsigned long int ip,int port,unsigned char options,char *miscptr,FILE *fp) {
     char *empty = "";
     char *pass, buffer[300];
 
@@ -38,29 +38,26 @@ int start_cisco_enable(int s,int port,unsigned char options,char *miscptr,FILE *
             }
             buf = hydra_receive_line(s);
 	}
-
     }
 
-    if (strstr(buf, "assw") != NULL || strstr(buf, "ad ") != NULL || strstr(buf, "attempt") != NULL || strstr(buf, "fail") != NULL) {
+    if (strstr(buf, "assw") != NULL || strstr(buf, "ad ") != NULL || strstr(buf, "attempt") != NULL || strstr(buf, "fail") != NULL || strstr(buf, "denied") != NULL) {
         free(buf);
         hydra_completed_pair();
         if (memcmp(hydra_get_next_pair(), &HYDRA_EXIT, sizeof(HYDRA_EXIT)) == 0)
             return 3;
-        return 1;
+        return 2;
     }
 
-    hydra_report_found(port, "cisco-enable", fp);
+    hydra_report_found_host(port, ip, "cisco-enable", fp);
     hydra_completed_pair_found();
-    if (memcmp(hydra_get_next_pair(), &HYDRA_EXIT, sizeof(HYDRA_EXIT)) == 0)
-        return 3;
-    free(buf);
-    return 1;
+    return 3;
 }
 
 void service_cisco_enable(unsigned long int ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
     int run = 1, failc = 0, retry = 1, next_run, sock = -1;
     int myport = PORT_TELNET, mysslport = PORT_TELNET_SSL;
     char buffer[300];
+    char *login;
 
     hydra_register_socket(sp);
     if (memcmp(hydra_get_next_pair(), &HYDRA_EXIT, sizeof(HYDRA_EXIT)) == 0)
@@ -70,8 +67,6 @@ void service_cisco_enable(unsigned long int ip, int sp, unsigned char options, c
         switch(run) {
             case 1: /* connect and service init function */
                    {
-                    unsigned char *buf2 = malloc(256);
-                    int f = 0;
                     if (sock >= 0) sock = hydra_disconnect(sock);
                     usleep(275000);
                     if ((options & OPTION_SSL) == 0) {
@@ -88,6 +83,19 @@ void service_cisco_enable(unsigned long int ip, int sp, unsigned char options, c
                         hydra_child_exit();
                     }
 
+          /* Cisco AAA Support */
+          if (strlen(login = hydra_get_next_login()) != 0) {
+            while ((buf = hydra_receive_line(sock)) != NULL && strstr(buf, "name") == NULL) {
+              free(buf);
+            }  
+
+            sprintf(buffer, "%.250s\r", login);
+            if (hydra_send(sock, buffer, strlen(buffer) + 1, 0) < 0) {
+              fprintf(stderr, "Error: Child with pid %d terminating, can not send login\n", (int)getpid());
+              hydra_child_exit();
+            } 
+          }
+
 		    while ((buf = hydra_receive_line(sock)) != NULL && strstr(buf, "assw") == NULL) {
 			free(buf);
 		    }	
@@ -105,6 +113,14 @@ void service_cisco_enable(unsigned long int ip, int sp, unsigned char options, c
                     }
 		    free(buf);
 		    
+          next_run = 2;
+          break;
+      }
+      case 2: /* run the cracking function */
+      {
+                    unsigned char *buf2 = malloc(256);
+                    int f = 0;
+
         	    sprintf(buffer, "%.250s\r\n", "ena");
         	    if (hydra_send(sock, buffer, strlen(buffer), 0) < 0) {
                         fprintf(stderr, "Error: Child with pid %d terminating, can not send 'ena'\n", (int)getpid());
@@ -129,13 +145,16 @@ void service_cisco_enable(unsigned long int ip, int sp, unsigned char options, c
                     free(buf2);
                     if (next_run != 0) break;
                     failc = 0;
-                    next_run = 2;
+
+                    next_run = start_cisco_enable(sock, ip, port, options, miscptr, fp);
                     break;
                    }
-            case 2: /* run the cracking function */
-                    next_run = start_cisco_enable(sock, port, options, miscptr, fp);
-                    break;
             case 3: /* clean exit */
+                    sprintf(buffer, "%.250s\r\n", "exit");
+                    if (hydra_send(sock, buffer, strlen(buffer), 0) < 0) {
+                        fprintf(stderr, "Error: Child with pid %d terminating, can not send 'exit'\n", (int)getpid());
+                        hydra_child_exit();
+                    }
                     if (sock >= 0) sock = hydra_disconnect(sock);
                     hydra_child_exit();
                     return;
@@ -146,4 +165,3 @@ void service_cisco_enable(unsigned long int ip, int sp, unsigned char options, c
         run = next_run;
     }
 }
-
