@@ -3,7 +3,7 @@
 extern char *HYDRA_EXIT;
 char *buf;
 
-int start_ftp(int s,unsigned char options,char *miscptr,FILE *fp) {
+int start_ftp(int s, unsigned long int ip, int port, unsigned char options,char *miscptr,FILE *fp) {
     char *empty = "\"\"";
     char *login, *pass, buffer[300];
     int i = 1;
@@ -12,9 +12,9 @@ int start_ftp(int s,unsigned char options,char *miscptr,FILE *fp) {
     if (strlen(pass = hydra_get_next_password()) == 0) pass = empty;
 
     while (i > 0 && hydra_data_ready(s) > 0)
-        i = recv(s, buffer, 300, 0);
+        i = hydra_recv(s, buffer, sizeof(buffer));
 
-    sprintf(buffer, "USER %.250s\n", login);
+    sprintf(buffer, "USER %.250s\r\n", login);
     if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
         return 1;
     }
@@ -27,7 +27,7 @@ int start_ftp(int s,unsigned char options,char *miscptr,FILE *fp) {
     }
     free(buf);
 
-    sprintf(buffer, "PASS %.250s\n", pass);
+    sprintf(buffer, "PASS %.250s\r\n", pass);
     if (hydra_send(s, buffer, strlen(buffer), 0) < 0) {
         return 1;
     }
@@ -35,8 +35,8 @@ int start_ftp(int s,unsigned char options,char *miscptr,FILE *fp) {
     if (buf == NULL)
         return 1;
     if (buf[0] == '2') {
-        hydra_report_found(fp);
-        hydra_completed_pair();
+        hydra_report_found_host(port, ip, "ftp", fp);
+        hydra_completed_pair_found();
         if (memcmp(hydra_get_next_pair(), &HYDRA_EXIT, sizeof(HYDRA_EXIT)) == 0)
             return 3;
         free(buf);
@@ -52,10 +52,10 @@ int start_ftp(int s,unsigned char options,char *miscptr,FILE *fp) {
 }
 
 void service_ftp(unsigned long int ip, int sp, unsigned char options, char *miscptr, FILE *fp, int port) {
-    int run = 1, next_run, sock = -1, myport = 21;
+    int run = 1, next_run, sock = -1;
+    int myport = PORT_FTP, mysslport = PORT_FTP_SSL;
 
     hydra_register_socket(sp);
-    if (port != 0) myport = port;
     if (memcmp(hydra_get_next_pair(), &HYDRA_EXIT, sizeof(HYDRA_EXIT)) == 0)
         return;
     while(1) {
@@ -63,8 +63,17 @@ void service_ftp(unsigned long int ip, int sp, unsigned char options, char *misc
             case 1: /* connect and service init function */
                     if (sock >= 0) sock = hydra_disconnect(sock);
                     usleep(300000);
-                    if ((sock = hydra_connect_tcp(ip, myport)) < 0) {
-                        fprintf(stderr, "Error: Child with pid %d terminating, can not connect\n", getpid());
+                    if ((options & OPTION_SSL) == 0) {
+                        if (port != 0) myport = port;
+                        sock = hydra_connect_tcp(ip, myport);
+			port = myport;
+                    } else {
+                        if (port != 0) mysslport = port;
+                        sock = hydra_connect_ssl(ip, mysslport);
+			port = mysslport;
+                    }
+                    if (sock < 0) {
+                        fprintf(stderr, "Error: Child with pid %d terminating, can not connect\n", (int)getpid());
                         hydra_child_exit();
                     }
                     usleep(300000);
@@ -81,12 +90,12 @@ void service_ftp(unsigned long int ip, int sp, unsigned char options, char *misc
                     usleep(1500000);
                     buf=malloc(1024);
                     while (hydra_data_ready(sock) > 0)
-                        recv(sock, buf, 1024, 0);
+                        hydra_recv(sock, buf, 1024);
                     free(buf);
                     next_run = 2;
                     break;
             case 2: /* run the cracking function */
-                    next_run = start_ftp(sock, options, miscptr, fp);
+                    next_run = start_ftp(sock, ip, port, options, miscptr, fp);
                     break;
             case 3: /* clean exit */
                     if (sock >= 0) sock = hydra_disconnect(sock);
