@@ -49,7 +49,7 @@ void tobase64(unsigned char *buf) {
     strcpy(buf, bof);
 }
 
-int start_http(int s, int port, unsigned char options,char *miscptr,FILE *fp) {
+int start_http(int s, unsigned long int ip, int port, unsigned char options,char *miscptr,FILE *fp) {
     char *empty = "";
     char *login, *pass, buffer[300], buffer2[110];
     char *header = "";  // XXX TODO:
@@ -82,7 +82,7 @@ int start_http(int s, int port, unsigned char options,char *miscptr,FILE *fp) {
 
     ptr = ((char*)index(buf, ' ')) + 1;
     if (*ptr == '2') {
-        hydra_report_found(port, "www", fp);
+        hydra_report_found_host(port, ip, "www", fp);
         hydra_completed_pair_found();
     } else {
         if (*ptr != '4')
@@ -129,7 +129,7 @@ void service_http(unsigned long int ip, int sp, unsigned char options, char *mis
                     break;
                    }
             case 2: /* run the cracking function */
-                    next_run = start_http(sock, port, options, miscptr, fp);
+                    next_run = start_http(sock, ip, port, options, miscptr, fp);
                     break;
             case 3: /* clean exit */
                     if (sock >= 0) sock = hydra_disconnect(sock);
