@@ -15,6 +15,7 @@ char *HYDRA_EMPTY = "\x00\x00\x00\x00";
 int fail = 0;
 int alarm_went_off = 0;
 int use_ssl = 0;
+char ipaddr_str[INET_ADDRSTRLEN];
 
 #ifdef OPENSSL
  SSL     *ssl = NULL;
@@ -211,6 +212,11 @@ void hydra_report_found(int port, char * svc, FILE *fp) {
     fprintf(fp, "[%d][%s] login: %s   password: %s\n",port, svc, hydra_get_next_login(),hydra_get_next_password());
 }
 
+void hydra_report_found_host(int port, unsigned int ip, char * svc, FILE *fp) {
+    inet_ntop(AF_INET, &ip, ipaddr_str, sizeof(ipaddr_str));
+    fprintf(fp, "[%d][%s] host: %s   login: %s   password: %s\n",port, svc, ipaddr_str, hydra_get_next_login(),hydra_get_next_password());
+}
+
 int hydra_connect_ssl(unsigned long int host, int port) {
 #ifdef OPENSSL
     return (internal__hydra_connect_ssl(host, port, SOCK_STREAM, 6));
