@@ -85,8 +85,7 @@ int smb_init(int s, char *name) {
  	return -1;	/* failed */
 }
 
-int 
-smb_login(int s, char *login, char *password) {
+int smb_login(int s, char *login, char *password) {
     int len = strlen(login) + strlen(password) + 57;
     int bcc = 2 + strlen(login) + strlen(password);
     int len_hi = len / 256, len_low = len % 256;
@@ -132,7 +131,7 @@ smb_login(int s, char *login, char *password) {
        return -1;
 }
 
-int start_smb(int s, int port, unsigned char options, char *miscptr, FILE *fp) {
+int start_smb(int s, unsigned long int ip, int port, unsigned char options, char *miscptr, FILE *fp) {
     char *empty = "";
     char *login, *pass;
 
@@ -140,7 +139,7 @@ int start_smb(int s, int port, unsigned char options, char *miscptr, FILE *fp) {
     if (strlen(pass = hydra_get_next_password()) == 0) pass = empty;
 	
     if(smb_login(s, login, pass) == 0) {
-        hydra_report_found(port, "smb", fp);
+        hydra_report_found_host(port, ip, "smb", fp);
         hydra_completed_pair_found();
         free(buf);
 	hydra_disconnect(s);
@@ -191,7 +190,7 @@ void service_smb(unsigned long int ip, int sp, unsigned char options, char *misc
                     next_run = 2;
                     break;
             case 2: /* run the cracking function */
-                    next_run = start_smb(sock, port, options, miscptr, fp);
+                    next_run = start_smb(sock, ip, port, options, miscptr, fp);
                     break;
             case 3: /* clean exit */
                     if (sock >= 0) sock = hydra_disconnect(sock);
