@@ -39,7 +39,7 @@ vncEncryptBytes(unsigned char *bytes, char *passwd)
     }
 }
 
-int start_vnc(int s,int port, unsigned char options,char *miscptr,FILE *fp) {
+int start_vnc(int s, unsigned long int ip, int port, unsigned char options,char *miscptr,FILE *fp) {
     char *empty = "";
     char *pass;
 
@@ -57,7 +57,7 @@ int start_vnc(int s,int port, unsigned char options,char *miscptr,FILE *fp) {
 
     if ((buf = hydra_receive_line(s)) == NULL) return(1);
     switch (buf[3]) {
-        case 0: hydra_report_found(port, "vnc", fp);
+        case 0: hydra_report_found_host(port, ip, "vnc", fp);
                 hydra_completed_pair_found();
                 free(buf);
                 if (memcmp(hydra_get_next_pair(), &HYDRA_EXIT, sizeof(HYDRA_EXIT)) == 0)
@@ -142,7 +142,7 @@ void service_vnc(unsigned long int ip, int sp, unsigned char options, char *misc
                     free(buf);
                     break;
             case 2: /* run the cracking function */
-                    next_run = start_vnc(sock, port, options, miscptr, fp);
+                    next_run = start_vnc(sock, ip, port, options, miscptr, fp);
                     break;
             case 3: /* clean exit */
                     if (sock >= 0) sock = hydra_disconnect(sock);
